Monty Python Flying Circus: Just the Words - Index of Characters

# Index of Characters

A B C D E F G H I J K L M N O P Q R S T U V W X Y Z

A
A, Mr
The mouse problem (2)
Confuse-a-Cat (5)
Accountant
The mouse problem (2)
The audit (7)
Adman
Commercials (26)
How to feed a goldfish (26)
Adrian
Gestures to indicate pauses in a televised talk (30)
Neurotic announcers (30)
African Native
Buying a bed (8)
Ageing General
Trivializing the war (42)
Airman
'When Does A Dream Begin?' (song) (42)
Akwekwe
Jungle restaurant (29)
Alan
How to rid the world of all known diseases (28)
Algy
Strangers in the night (10)
Biggles dictates a letter (33)
Ali Byan
'Crackpot Religions Ltd' (24)
Alphonse
Election Night Special (Silly and Sensible Parties) (19)
An Old Gramophone
City gents vox pops (24)
Anchovy
Vocational Guidance Counseller (chartered accountant) (10)
Anemone, Mr
Flying lessons (16)
Angus
Man turns into Scotsman (7)
Police station (7)
Animated Character
Operating theatre (squatters) (13)
Another Man
Complaints (16)
Vox pops on aftershave (17)
Mr Neville Shunt (24)
Ant Expert
Ant communication (41)
Antoinette
Montgolfier Brothers (40)
George III (40)
Architect
Mystico and Janet - flats built by hypnosis (35)
Art Critic
Art critic - the place of the nude (8)
Mr Neville Shunt (24)
Arthur
Secret Service dentists (4)
The visitors (9)
Assistant
Buying a bed (8)
Bank robber (lingerie shop) (10)
Killer sheep (20)
Tudor job agency (36)
Pornographic bookshop (36)
Department store (41)
Buying an ant (41)
Complaining about ant (41)
Different endings (41)
Boxing match aftermath (43)
Attenborough
David Attenborough (45)
The walking tree of Dahomey (45)
Attendant
'Mortuary Hour' (35)
Poetry reading (ants) (41)
Attila
Mr Attila the Hun (13)
'The Attila the Hun Show' (20)
Attila the Hun
Mr Attila the Hun (13)
Attila, Mrs
'The Attila the Hun Show' (20)
Auctioneer
Art gallery strike (25)
Audience
Puss in Boots (28)
George III (40)
Audrey
The visitors (9)

B
B, Mrs
Confuse-a-Cat (5)
Badger
The silliest interview we've ever had (32)
The silliest sketch we've ever done (32)
Bomb on plane (35)
'Mortuary Hour' (35)
The Olympic hide-and-seek final (35)
The Cheap-Laughs (35)
The British Well-Basically Club (35)
Prices on the planet Algon (35)
Bag
Bingo-crazed Chinese (34)
Baker
The news with Richard Baker (30)
Balderston
Schoolboys' Life Assurance Company (28)
BALPA Man
Flying lessons (16)
Complaints (16)
Bandit
Vox pops (6)
Bank Manager
The Idiot in Society (20)
Barbara
Vox pops on full frontal nudity (8)
Barber
Homicidal barber (9)
Lumberjack song (9)
The refreshment room at Bletchley (9)
Barnard, Mr
Hitting on the head lessons (29)
Barnes
Escape (from film) (18)
Bartlett
George III (40)
Bartlett, Mr
Montgolfier Brothers (40)
Louis XIV (40)
Battersby
'Mortuary Hour' (35)
Baxter
Picasso/cycling race (1)
BBC Man
Jokes and novelties salesman (15)
Words not to be used again (17)
Bee
Job Hunter (24)
Beethoven
Beethoven's mynah bird (21)
Shakespeare (21)
Colin Mozart (ratcatcher) (21)
Beethoven, Mrs
Beethoven's mynah bird (21)
Colin Mozart (ratcatcher) (21)
Bert
Climbing the north face of the Uxbridge Road (33)
Beryl
Stonehenge (13)
Mr Attila the Hun (13)
Bevis
Erotic film (5)
Bicycle Repair Man
Bicycle repair man (3)
Big Cheese
Secret Service dentists (4)
Biggles
Strangers in the night (10)
The Spanish Inquisition (15)
Photos of Uncle Ted (Spanish Inquisition) (15)
Court scene (charades) (15)
Biggles dictates a letter (33)
Bill
'Crackpot Religions Ltd' (24)
Bishop
The audit (7)
A bishop rehearsing (16)
Complaints (16)
Déjà vu (16)
'The Bishop' (17)
A choice of viewing (17)
Accidents sketch (18)
School prize-giving (19)
'Crackpot Religions Ltd' (24)
Brigadier and Bishop (45)
Bishop & Saint
Johann Gambolputty.... von Hautkopf of Ulm (6)
Bishops
'Take Your Pick' (20)
Black Man
Boxing match aftermath (43)
Blancmange Umpire
Blancmanges playing tennis (7)
Block
Arthur Tree (10)
The Piranha brothers (14)
Boar
Johann Gambolputty.... von Hautkopf of Ulm (6)
Board Member
The audit (7)
Bob
Kilimanjaro expedition (double vision) (9)
Bones, Mr
Off-Licence (37)
Boniface
Complaints (16)
Déjà vu (16)
Bookseller
Secret Service dentists (4)
Booth
Language laboratory (31)
Boss
Non-illegal robbery (6)
Conquistador Coffee Campaign (24)
The man who makes people laugh uncontrollably (30)
Botticelli Lover
Johann Gambolputty.... von Hautkopf of Ulm (6)
Bounder
Travel agent (31)
Watney's Red Barrel (31)
Theory on Brontosauruses by Anne Elk (Miss) (31)
Bovril
RAF banter (42)
Boy
Letters and vox pops (5)
Boys
Seven Brides for Seven Brothers (18)
Braddon
'Prejudice' (37)
Bradford
Toupee (41)
Brainsample, Mr
Blancmanges playing tennis (7)
Brian
Secret Service dentists (4)
Test match (20)
Live from Epsom (43)
Queen Victoria Handicap (43)
Brian Clough
Different endings (41)
Bride
Buying a bed (8)
Brigadier
The British Well-Basically Club (35)
Brigadier and Bishop (45)
Briggs
Credits of the Year (39)
British Fish
World War One (28)
Brooky
Current affairs (18)
Bruce
Bruces (22)
Bruce, Dr
Bogus psychiatrists (43)
Buckingham
Lupins (37)
Dennis Moore: Stealing from the poor (37)
Bumpkin
Art gallery strike (25)
Bun, Mr
Spam (25)
Bun, Mrs
Spam (25)
Burrows
The man who says words in the wrong order (36)
Business Man
Vox pops on tax (15)
Butcher
The man who is alternately rude and polite (18)
Butler
Accidents sketch (18)
Montgolfier Brothers (40)
Louis XIV (40)
George III (40)
Buzzard
Literary football discussion (11)
Interesting people (11)

C
Caesar
Pet conversions (10)
Historical impersonations (13)
Camera Crew
Six more minutes of Monty Python's Flying Circus (29)
Cameraman
Living room on pavement (17)
Canning
Interruptions (11)
Eighteenth-century social legislation (11)
The Battle of Trafalgar (11)
Batley Townswomens' Guild presents the Battle of Pearl Harbour (11)
Undertakers film (11)
Captain
World War One (28)
The BBC is short of money (28)
Puss in Boots (28)
Kamikaze Scotsmen (38)
No time to lose (38)
Trivializing the war (42)
Captain Carpenter
Mr Neutron (44)
Cardinal
Court scene (witness in coffin/Cardinal Richelieu) (3)
Cardinal Ximinez
Vox pops on aftershave (17)
Carol
Father-in-law (43)
Carpenter
Mr Neutron (44)
Teddy Salad (CIA agent) (44)
Cartoon City Gent
How to give up being a Mason (17)
CAS, Mrs
Documentary on boxer (18)
Casey, Mr
International Wife-Swapping (39)
Chairman
The smuggler (5)
Vox pops on smuggling (5)
The audit (7)
Gorilla librarian (10)
'Up Your Pavement' (42)
Teddy Salad (CIA agent) (44)
Character
The first underwater production of 'Measure for Measure' (22)
Charles
Man turns into Scotsman (7)
Police station (7)
Blancmanges playing tennis (7)
Sam Peckinpah's 'Salad Days' (33)
Charlton
Bogus psychiatrists (43)
Chartered Accountant
Vox pops (6)
Buying a bed (8)
Cheap-Laugh, Mr
The Cheap-Laughs (35)
Cheap-Laugh, Mrs
The Cheap-Laughs (35)
Chemist
Chemist sketch (17)
Words not to be used again (17)
After-shave (17)
Vox pops on aftershave (17)
Police Constable Pan-Am (17)
Cherub
Art gallery strike (25)
Chief Constable
Stonehenge (13)
Mr Attila the Hun (13)
Chief Executive
The public are idiots (42)
The last five miles of the M2 (42)
Chigger, Mr
A bishop rehearsing (16)
Flying lessons (16)
Chinaman
School prize-giving (19)
Bingo-crazed Chinese (34)
Chinese Fish
World War One (28)
Chinese Hordes
Bingo-crazed Chinese (34)
Chip
Arthur Tree (10)
Chivers
The dirty vicar sketch (39)
Choreographer
Party Political Broadcast (choreographed) (38)
Chris
Climbing the north face of the Uxbridge Road (33)
Department store (41)
Buying an ant (41)
At home with the ant and other pets (41)
Ant communication (41)
Complaining about ant (41)
Toupee (41)
Complaints office (41)
Different endings (41)
Church Policeman
Salvation fuzz (29)
Cinema Manager
Hell's Grannies (8)
City Gent
Flying Sheep (2)
Quiz programme - 'Wishes' (13)
The Ministry of Silly Walks (14)
Architect sketch (17)
City gents vox pops (24)
Merchant banker (30)
Pantomime horses (30)
The man who makes people laugh uncontrollably (30)
City Idiot
The Idiot in Society (20)
Clapper Boy
Timmy Williams interview (19)
Clerk
Court scene (charades) (15)
The Idiot in Society (20)
Court (phrasebook) (25)
Court scene (Viking) (27)
Erizabeth L (29)
The free repetition of doubtful words sketch, by an underrated author (36)
Clerk of the Court
Court scene (witness in coffin/Cardinal Richelieu) (3)
Cliff
Derby Council v. All Blacks rugby match (23)
Climber
Everest climbed by hairdressers (31)
Coachman
Dennis Moore (37)
Coelocanth
Strangers in the night (10)
Colin
Election Night Special (Silly and Sensible Parties) (19)
Colin Mozart
Colin Mozart (ratcatcher) (21)
Collins, Mrs
'Crackpot Religions Ltd' (24)
Colonel
The funniest joke in the world (1)
It's a man's life in the modern army (4)
Undressing in public (4)
Self-defence (4)
Secret Service dentists (4)
Army protection racket (8)
Buying a bed (8)
Hermits (8)
Dead parrot (8)
Hell's Grannies (8)
Everest climbed by hairdressers (31)
Colonel Ewing
Complaints office (41)
Colonel Pickering
Agatha Christie sketch (11)
Colonel Type
Documentary on boxer (18)
Commander
Mr Neutron (44)
Teddy Salad (CIA agent) (44)
Commanding NCO
The funniest joke in the world (1)
Commentator
The funniest joke in the world (1)
Bicycle repair man (3)
Blancmanges playing tennis (7)
Upperclass Twit of the Year (12)
The Epsom furniture race (20)
Derby Council v. All Blacks rugby match (23)
Puss in Boots (28)
Molluscs - 'live' TV documentary (32)
The Olympic hide-and-seek final (35)
Cricket match (assegais) (45)
Compère
A man with two noses (2)
Children's stories (3)
Restaurant sketch (3)
The refreshment room at Bletchley (9)
Arthur Tree (10)
Literary football discussion (11)
Interesting people (11)
'It's a Living' (19)
Secretary of State striptease (20)
'Russian 42nd International Clambake' (34)
Complaints Manager
Complaints office (41)
Computer
Bogus psychiatrists (43)
Conclusion, Mrs
Mrs Premise and Mrs Conclusion visit Jean Paul Satre (27)
Concrete, Mr
Vox pops on politicians (20)
Ratcatcher (20)
Wainscotting (20)
Concrete, Mrs
Ratcatcher (20)
Wainscotting (20)
Conger
Scott of the Antarctic (23)
Conjurer
'Conjuring Today' (44)
Constable
Agatha Christie sketch (11)
Literary football discussion (11)
Court scene (Viking) (27)
Consultant
No time to lose (38)
Cook
Restaurant sketch (3)
Cook, Mr
The visitors (9)
Corporal
Trivializing the war (42)
Counsel
Court scene (witness in coffin/Cardinal Richelieu) (3)
Court scene (charades) (15)
Court scene - multiple murderer (27)
Counsellor
Marriage guidance counsellor (2)
Vocational Guidance Counseller (chartered accountant) (10)
Court
Court scene - multiple murderer (27)
Court scene (Viking) (27)
Fraud film squad (29)
Crackpot
'Crackpot Religions Ltd' (24)
Crawley
Toupee (41)
Cream, Dr
Psychiatrist milkman (16)
Complaints (16)
Déjà vu (16)
Cricket Team
Johann Gambolputty.... von Hautkopf of Ulm (6)
Cricketer
'Spectrum' - talking about things (12)
Wainscotting (20)
Killer sheep (20)
Pasolini's film 'The Third Test Match' (39)
Criminologist
The Piranha brothers (14)
Critic
Art critic (4)
Documentary on boxer (18)
Art gallery strike (25)
Crocodile
Strangers in the night (10)
Curry
Film director (teeth) (24)
Customer
Homicidal barber (9)
The refreshment room at Bletchley (9)
Tobacconists (prostitute advert) (14)
Tudor job agency (36)
Pornographic bookshop (36)
Cutler, Mr
Society for Putting Things on top of Other Things (18)
Escape (from film) (18)
Cyril
Today in Parliament (20)

D
Dad
Working-class playwright (2)
Policemen make wonderful friends (6)
'Most Awful Family in Britain' (45)
Icelandic Honey Week (45)
Dame Elsie
'Spot the Loony' (38)
Dame Irene
Foreign Secretary (19)
Dancers
Party Political Broadcast (choreographed) (38)
Danielle
'Archaeology Today' (21)
Darnay
The news for parrots (20)
Daughter
Woody and tinny words (42)
David
The Poet McTeagle (16)
David Hamilton
Thames TV introduction (39)
Dead Indian
Dead Indian (19)
Dear Old Lady
Photos of Uncle Ted (Spanish Inquisition) (15)
Defence
Court (phrasebook) (25)
Defense Counsel
'Anything Goes In' (song) (42)
Dentist
Dentists (43)
Derek
A choice of viewing (17)
Desk Clerk
Smolensk (34)
Bingo-crazed Chinese (34)
Detective
Police station (7)
School prize-giving (19)
Devious
Motor insurance sketch (17)
'The Bishop' (17)
Dibley
'if' - a film by Mr Dibley (19)
'Rear Window' - a film by Mr Dibley (19)
'Finian's Rainbow' (starring the man from the off-license) (19)
Dick
Neurotic announcers (30)
Dickens
'Spot the Loony' (38)
Dickie
'Light Entertainment Awards' (39)
The Oscar Wilde sketch (39)
David Niven's fridge (39)
Credits of the Year (39)
The dirty vicar sketch (39)
Dickie Attenborough
New brain from Curry's (39)
Dim
Court scene (witness in coffin/Cardinal Richelieu) (3)
Dinner Crowd
Pornographic bookshop (36)
Dino
Army protection racket (8)
Director
Timmy Williams interview (19)
Six more minutes of Monty Python's Flying Circus (29)
Dobbin
'The Pantomime Horse is a Secret Agent' (30)
Doctor
Johann Gambolputty.... von Hautkopf of Ulm (6)
Me Doctor (13)
The Poet McTeagle (16)
Psychiatrist milkman (16)
Documentary on boxer (18)
Attila the Nun (20)
Silly doctor sketch (immediately abandoned) (21)
There's been a murder (22)
Hospital run by RSM (26)
Vicar/salesman (28)
Mr Pither (34)
Clodagh Rodgers (34)
Doctor (37)
Piston engine (a bargain) (43)
A doctor whose patients are stabbed by his nurse (45)
Dog
Teddy Salad (CIA agent) (44)
Donor
Blood donor (39)
Dorian
Show-jumping (musical) (42)
Dorian Williams
Puss in Boots (28)
Doris
Old lady snoopers (33)
Dorothy Lamour
Expedition to Lake Pahoe (32)
Dove
Interesting people (11)
Driver
Mr Pither (34)
Duckie
Europolice Song Contest (22)
Duke
Louis XIV (40)
George III (40)

E
Eamonn
Our Eamonn (31)
Eddie
Famous deaths (1)
Eddie Waring
International Wife-Swapping (39)
Edwards, Mrs
Old lady snoopers (33)
Elizabeth III, Mrs
The public are idiots (42)
The last five miles of the M2 (42)
Show-jumping (musical) (42)
Elizabethan Gent
Pornographic bookshop (36)
Elk, Miss
Theory on Brontosauruses by Anne Elk (Miss) (31)
Enid
Old lady snoopers (33)
Entrail, Mr
Mr Neutron (44)
Entrail, Mrs
Mr Neutron (44)
Equator, Mr
The visitors (9)
Eric
Children's interview (3)
Quiz programme - 'Wishes' (13)
Election Night Special (Silly and Sensible Parties) (19)
Eskimo
Teddy Salad (CIA agent) (44)
Eskimos
Teddy Salad (CIA agent) (44)
Evans
Scott of the Antarctic (23)
Everybody
Dirty Hungarian phrasebook (25)
Everyone
Escape (from film) (18)
'Anything Goes In' (song) (42)
The last five miles of the M2 (42)
Ewing
Musical mice (2)
Executive
Flying lessons (16)
Expert
'Life of Tschaikowsky' (28)
Explorer
Jungle restaurant (29)
The Lost World of Roiurama (29)
Six more minutes of Monty Python's Flying Circus (29)

F
F. G. Superman
Bicycle repair man (3)
Fairy
Quiz programme - 'Wishes' (13)
Family Group
Johann Gambolputty.... von Hautkopf of Ulm (6)
Fang
The Spanish Inquisition (15)
Photos of Uncle Ted (Spanish Inquisition) (15)
Father
Ken Shabby (12)
Pornographic bookshop (36)
Woody and tinny words (42)
Father-in-law (43)
Father Pierre
Whicker Island (27)
Fawcett
Courtmartial (42)
Basingstoke in Westphalia (42)
'Anything Goes In' (song) (42)
Feldman
Insurance sketch (26)
Female Peasant
Lupins (37)
Dennis Moore: Stealing from the poor (37)
Fifth
Non-illegal robbery (6)
Figgis
'It's the arts' (6)
Johann Gambolputty.... von Hautkopf of Ulm (6)
The Idiot in Society (20)
Fire
Agatha Christie sketch (11)
Firema, A
Our Eamonn (31)
Fireman
Dirty Hungarian phrasebook (25)
Fire brigade (31)
Firemen
Our Eamonn (31)
Floor Manager
Hunting film (9)
Walk-on part in sketch (10)
Current affairs (18)
'Ypres 1914' - abandoned (25)
Ford, Mr
Merchant banker (30)
Foreman
Court scene (charades) (15)
Coal mine (historical argument) (26)
Court scene - multiple murderer (27)
M1 interchange built by characters from 'Paradise Lost' (35)
Forestry Expert
Rival documentaries (38)
Foster
Famous deaths (1)
Fox
One more minute of Monty Python's Flying Circus (29)
Frampton
A man with three buttocks (2)
Francesco
Italian lesson (1)
Francisco
The Olympic hide-and-seek final (35)
Frank Bough
The Olympic hide-and-seek final (35)
International Wife-Swapping (39)
Fred
Undertaker's sketch (26)
Fred's voice
Undertaker's sketch (26)
Freight, Mr
The visitors (9)
French Au Pair
Vox pops on smuggling (5)
French Girl
Trotsky (34)
Frenchman
French lecture on sheep-aircraft (2)
The Ministry of Silly Walks (14)
Trotsky (34)
Fridge
David Niven's fridge (39)
Friend
Dennis Moore: Redistibuting the wealth (37)
Frog
Conquistador Coffee Campaign (24)

G
Gabriello, Mr
Boxing match aftermath (43)
Garibaldi, Mr
'Most Awful Family in Britain' (45)
Garibaldi, Mrs
'Most Awful Family in Britain' (45)
Gary
Trim-Jeans Theatre (28)
Gas Man
New cooker sketch (14)
Dead Indian (19)
Gaskell
Pornographic bookshop (36)
General
Confuse-a-Cat (5)
'Russian 42nd International Clambake' (34)
Trivializing the war (42)
Generals
The funniest joke in the world (1)
Genevieve
Trotsky (34)
Gent
The man who is alternately rude and polite (18)
George
Election Night Special (Silly and Sensible Parties) (19)
George III
George III (40)
Geppo
Picasso/cycling race (1)
Gerald
Election Night Special (Silly and Sensible Parties) (19)
German
Italian lesson (1)
German Joker
The funniest joke in the world (1)
German Officer
Escape (from film) (18)
Ginger
Biggles dictates a letter (33)
Giraffe
Police station (silly voices) (12)
Girl
You're no fun any more (7)
Police station (7)
Art critic - the place of the nude (8)
Lumberjack song (9)
Operating theatre (squatters) (13)
Words not to be used again (17)
Vox pops on politicians (20)
Europolice Song Contest (22)
French subtitled film (23)
Scott of the Antarctic (23)
'The Pantomime Horse is a Secret Agent' (30)
Mr Pither (34)
Pornographic bookshop (36)
Dennis Moore (37)
Different endings (41)
Git, Mr
Mr and Mrs Git (21)
Git, Mrs
Mr and Mrs Git (21)
Giuseppe
Italian lesson (1)
Teddy Salad (CIA agent) (44)
Gladys
Old lady snoopers (33)
Complaining about ant (41)
Glans
Job Hunter (24)
Gloria
The Piranha brothers (14)
Gorilla
Gorilla librarian (10)
Gorilla, Mrs
Piston engine (a bargain) (43)
GPO Official
Post box ceremony (44)
Teddy Salad (CIA agent) (44)
Granny
Hell's Grannies (8)
Grantley
Lupins (37)
Dennis Moore: Stealing from the poor (37)
Grayson, Mr
Interview in filing cabinet (24)
Green
Accidents sketch (18)
Grimshaw
Blood donor (39)
Grip
Bingo-crazed Chinese (34)
Groom
Buying a bed (8)
Guard
Trim-Jeans Theatre (28)
World War One (28)
The BBC is short of money (28)
Puss in Boots (28)
Guitarist & Dancer
Llamas (9)
Gulliver
Accidents involving food (34)
Trotsky (34)
Smolensk (34)
'Russian 42nd International Clambake' (34)
Gumby
Gumby crooner (9)
The Battle of Trafalgar (11)
The Minehead by-election (12)
Historical impersonations (13)
Vox pops on tax (15)
Vox pops on aftershave (17)
'Crackpot Religions Ltd' (24)
Gumby flower arranging (25)
Gumby Anaesthetist
Gumby brain specialist (32)
Gumbys
How to give up being a Mason (17)
A choice of viewing (17)
Police Constable Pan-Am (17)
Gunman
Hijacked plane (to Luton) (16)

H
Hamer, Dr
George III (40)
Hamlet
Bogus psychiatrists (43)
Hamlet and Ophelia (43)
Queen Victoria Handicap (43)
Hamlets
Hospital for over-actors (25)
Hank
Mosquito hunters (21)
Hardacre
'Spectrum' - talking about things (12)
Hardy
Film director (teeth) (24)
Hargreaves
Six more minutes of Monty Python's Flying Circus (29)
Harry
Pet conversions (10)
'Summarize Proust Competition' (31)
Prices on the planet Algon (35)
Hartebeeste
Strangers in the night (10)
Hartford
Buying an ant (41)
He
Restaurant (abuse/cannibalism) (13)
Silly disturbances (the Rev. Arthur Belling) (36)
Head of Drama
Mrs Premise and Mrs Conclusion visit Jean Paul Satre (27)
Head Waiter
Restaurant sketch (3)
Restaurant (abuse/cannibalism) (13)
Headmaster
Restaurant (abuse/cannibalism) (13)
Seven Brides for Seven Brothers (18)
Schoolboys' Life Assurance Company (28)
Headphones
Bomb on plane (35)
Hedgehog
The Piranha brothers (14)
Helmut
Zeppelin (40)
Helmut, Mrs
Zeppelin (40)
Henson
Doctor (37)
Herbert
The man who collects birdwatcher's eggs (26)
Hermit
Hermits (8)
Highlander
The Poet McTeagle (16)
Highwayman
'Prejudice' (37)
Hijacker
Hijacked plane (to Luton) (16)
Him
Nudge nudge (3)
Himmler
Mr Hilter (12)
The Minehead by-election (12)
Historian
Spam (25)
Hitler
Mr Hilter (12)
The Minehead by-election (12)
Hoad
Penguins (38)
BBC programme planners (38)
Hollweg
Zeppelin (40)
Hopkins
Restaurant (abuse/cannibalism) (13)
Host
Dung (19)
Dead Indian (19)
Mr and Mrs Git (21)
Hostess
Flying lessons (16)
Hijacked plane (to Luton) (16)
Dung (19)
Dead Indian (19)
House Manager
Red Indian in theatre (6)
Housewife
Dentists (43)
Hungarian
Dirty Hungarian phrasebook (25)
Spam (25)
Huntingdon
Housing project built by characters from nineteenth-century English literature (35)
Husband
Strangers in the night (10)
Sherry-drinking vicar (36)

I
Ian
The Poet McTeagle (16)
Idiot
The Idiot in Society (20)
Indian
Red Indian in theatre (6)
Operating theatre (squatters) (13)
Inference, Mrs
Mrs Premise and Mrs Conclusion visit Jean Paul Satre (27)
Inspector
The funniest joke in the world (1)
Man turns into Scotsman (7)
Agatha Christie sketch (11)
Police station (silly voices) (12)
Come back to my place (13)
Poets (17)
A choice of viewing (17)
Dead Indian (19)
Agatha Christie Sketch (Railway Timetables) (24)
Fraud film squad (29)
Six more minutes of Monty Python's Flying Circus (29)
One more minute of Monty Python's Flying Circus (29)
Inspector Praline
Vox pops (6)
Inspector Tiger
Agatha Christie sketch (11)
Interviewer
Whizzo butter (1)
It's the Arts (1)
Arthur 'Two-Sheds' Jackson (1)
French lecture on sheep-aircraft (2)
A man with three buttocks (2)
The wrestling epilogue (2)
The mouse problem (2)
Children's interview (3)
Silly job interview (5)
Johann Gambolputty.... von Hautkopf of Ulm (6)
Camel spotting (7)
You're no fun any more (7)
The first man to jump the Channel (10)
Tunnelling from Godalming to Java (10)
Literary football discussion (11)
The Minehead by-election (12)
Quiz programme - 'Wishes' (13)
'Probe-around' on crime (13)
'Face the Press' (14)
The Piranha brothers (14)
The Poet McTeagle (16)
Living room on pavement (17)
'if' - a film by Mr Dibley (19)
'Finian's Rainbow' (starring the man from the off-license) (19)
Foreign Secretary (19)
Raymond Luxury Yacht interview (19)
The Idiot in Society (20)
'Archaeology Today' (21)
The man who contradicts people (22)
Cosmetic surgery (22)
Camp square-bashing (22)
'Crackpot Religions Ltd' (24)
The man who says things in a very roundabout way (26)
The man who speaks only the ends of words (26)
The man who speaks only the beginnings of words (26)
The man who speaks only the middles of words (26)
'Blood, Devastation, Death, War and Horror' (30)
The man who speaks in anagrams (30)
Expedition to Lake Pahoe (32)
The silliest interview we've ever had (32)
The silliest sketch we've ever done (32)
Climbing the north face of the Uxbridge Road (33)
Thripshaw's disease (36)
Iris
The visitors (9)
Irrelevant, Mr
Cut-price airline (22)
Irrelevant, Mrs
Cut-price airline (22)
It's Man
Man-powered flight (15)
Vox pops on tax (15)
'The Attila the Hun Show' (20)
Scott of the Sahara (23)
Repeating groove (24)
'The Black Eagle' (25)
Emigration from Surbiton to Hounslow (28)
Puss in Boots (28)
The man who speaks in anagrams (30)
Tory Housewives Clean-up Campaign (32)
The show so far (33)
A naked man (35)
Silly disturbances (the Rev. Arthur Belling) (36)
'Boxing tonight' - Jack Bodell v. Kenneth Clark (37)
Party Political Broadcast (choreographed) (38)
Thames TV introduction (39)
Film trailer (42)
Italian
Teddy Salad (CIA agent) (44)
Ith, Mr
The man who speaks only the ends of words (26)
The man who speaks only the beginnings of words (26)
The man who speaks only the middles of words (26)

J
Jack
Documentary on boxer (18)
Neurotic announcers (30)
Jackie
How to rid the world of all known diseases (28)
Jackson
Arthur 'Two-Sheds' Jackson (1)
Jacques
Montgolfier Brothers (40)
Louis XIV (40)
George III (40)
Jalin, Mr
Molluscs - 'live' TV documentary (32)
Jalin, Mrs
Molluscs - 'live' TV documentary (32)
Janet
Art gallery (4)
Japanese
Erizabeth L (29)
Jasmina
Agatha Christie Sketch (Railway Timetables) (24)
Jean
Trim-Jeans Theatre (28)
Jean-Paul
Mrs Premise and Mrs Conclusion visit Jean Paul Satre (27)
Jenkins
'Ypres 1914' - abandoned (25)
'Ypres 1914' (25)
Jenkins, Mr
The Idiot in Society (20)
Jenny
'The Attila the Hun Show' (20)
Jeremy
'Redgauntlet' (38)
Kamikaze Scotsmen (38)
Jewish Figure
The audit (7)
Jim
Test match (20)
Jimmy
Kilimanjaro expedition (double vision) (9)
Jimmy Hill
Queen Victoria Handicap (43)
Jockey
Live from Epsom (43)
Joe-jums
Neurotic announcers (30)
John
The Piranha brothers (14)
Mr and Mrs Git (21)
Agatha Christie Sketch (Railway Timetables) (24)
Johnson
Visitors from Coventry (12)
Mr Hilter (12)
The Minehead by-election (12)
Jokes and novelties salesman (15)
Johnson, Miss
Job Hunter (24)
Johnson, Mr
Visitors from Coventry (12)
Joke Brigade
The funniest joke in the world (1)
Joke Corporal
The funniest joke in the world (1)
Joseph
Montgolfier Brothers (40)
Louis XIV (40)
George III (40)
Journalist
Court (phrasebook) (25)
Judge
Court scene (witness in coffin/Cardinal Richelieu) (3)
Vox pops (6)
Court scene (charades) (15)
Poofy judges (21)
Judges (21)
Court scene - multiple murderer (27)
Court scene (Viking) (27)
Judge Kilbraken
Court scene (charades) (15)
Julian
Sam Peckinpah's 'Salad Days' (33)
Julius
Film director (teeth) (24)
Juryman
Court scene - multiple murderer (27)

K
Kamikaze
Cut-price airline (22)
Kargol
The mouse problem (2)
Karl
Johann Gambolputty.... von Hautkopf of Ulm (6)
Communist quiz (25)
Kastner
'Archaeology Today' (21)
Keats
Poetry reading (ants) (41)
Kelly, Mr
Puss in Boots (28)
Kelly, Mrs
Puss in Boots (28)
Ken
Working-class playwright (2)
Kennedy
'TV4 or not TV4' diskussion (37)
Kevin
The Idiot in Society (20)
Kevin Garibaldi
'Most Awful Family in Britain' (45)
Kinwoodie
'TV4 or not TV4' diskussion (37)
Kirkham
Sherry-drinking vicar (36)
Knight
Trim-Jeans Theatre (28)
Knight in Armour
Johann Gambolputty.... von Hautkopf of Ulm (6)
Knitting Policeman
Watney's Red Barrel (31)

L
Labienus
Film director (teeth) (24)
Labour MPs
Party Political Broadcast (choreographed) (38)
Lad, A
Strangers in the night (10)
Lady
Restaurant sketch (3)
Tunnelling from Godalming to Java (10)
Psychiatrist milkman (16)
Complaints (16)
Lupins (37)
Dennis Moore: Stealing from the poor (37)
The dirty vicar sketch (39)
Department store (41)
Complaints office (41)
Lady Mountback
The Spanish Inquisition (15)
Lady Organs
'Most Awful Family in Britain' (45)
Lady Partridge
Agatha Christie Sketch (Railway Timetables) (24)
Lady Velloper
Agatha Christie sketch (11)
Lafarge
Secret Service dentists (4)
Lambert
Buying a bed (8)
Lambert, Mr
Buying a bed (8)
Landlady
Visitors from Coventry (12)
Mr Hilter (12)
The Minehead by-election (12)
Larry
Non-illegal robbery (6)
Twentieth-century vole (6)
Lashee
You're no fun any more (7)
Lasher
You're no fun any more (7)
Lassie
The Poet McTeagle (16)
Leavey, Mr
Architect sketch (17)
Leicester
Erizabeth L (29)
Lennon
'Crackpot Religions Ltd' (24)
Lifeboatman
Lifeboat (33)
Old lady snoopers (33)
Lift Woman
Complaining about ant (41)
Limbo
The Poet McTeagle (16)
Linkman
It's the Arts (1)
Arthur 'Two-Sheds' Jackson (1)
Picasso/cycling race (1)
The mouse problem (2)
Live from the Grill-o-Mat snack bar, Paignton (18)
Escape (from film) (18)
Current affairs (18)
Accidents sketch (18)
The man who is alternately rude and polite (18)
Documentary on boxer (18)
Election Night Special (Silly and Sensible Parties) (19)
Derby Council v. All Blacks rugby match (23)
The man who finishes other peoples sentences (45)
BBC News (handovers) (45)
Lionel
Sam Peckinpah's 'Salad Days' (33)
Little, Mrs
Fire brigade (31)
Our Eamonn (31)
Livingstone
Bingo-crazed Chinese (34)
Lon Chaney
Johann Gambolputty.... von Hautkopf of Ulm (6)
Long John Silver
Confuse-a-Cat (5)
Long Name, Mrs
Appeal on behalf of extremely rich people (45)
The man who finishes other peoples sentences (45)
Lookout
Agatha Christie sketch (11)
Loone
'TV4 or not TV4' diskussion (37)
Loony
'The Pantomime Horse is a Secret Agent' (30)
Molluscs - 'live' TV documentary (32)
Biggles dictates a letter (33)
Lord Interest
Louis XIV (40)
Lord North
George III (40)
Loudspeaker
Teddy Salad (CIA agent) (44)
Louis
Louis XIV (40)
George III (40)
Lovely Girl
Police station (silly voices) (12)
Lucy
The news for parrots (20)
Luigi
Army protection racket (8)
Lulu
Puss in Boots (28)
Lumberjack
Teddy Salad (CIA agent) (44)
Luxury Yacht, Mr
Cosmetic surgery (22)

M
M'Burke
Prices on the planet Algon (35)
M. Brun
Trotsky (34)
MacDonald
No time to lose (38)
MacPherson
Kamikaze Scotsmen (38)
Madd
The Minehead by-election (12)
Maddox
Pornographic bookshop (36)
Madly Dressed Man
City gents vox pops (24)
Magistrate
Court (phrasebook) (25)
Maid
Accidents sketch (18)
Major
'Ypres 1914' (25)
Unexploded Scotsman (38)
Make-up Girl
'Redgauntlet' (38)
No time to lose (38)
Malcolm Allison
Different endings (41)
Male Peasant
Lupins (37)
Dennis Moore: Stealing from the poor (37)
Man
Marriage guidance counsellor (2)
Working-class playwright (2)
The mouse problem (2)
Restaurant sketch (3)
It's a man's life in the modern army (4)
Self-defence (4)
The smuggler (5)
Vox pops on smuggling (5)
Silly job interview (5)
Burglar/encyclopedia salesman (5)
Johann Gambolputty.... von Hautkopf of Ulm (6)
The dull life of a City stockbroker (6)
Red Indian in theatre (6)
Vox pops on full frontal nudity (8)
Llamas (9)
Walk-on part in sketch (10)
Pet conversions (10)
Interesting people (11)
Eighteenth-century social legislation (11)
Falling from building (12)
Police station (silly voices) (12)
How far can a minister fall? (12)
Albatross (13)
Come back to my place (13)
Me Doctor (13)
New cooker sketch (14)
The Ministry of Silly Walks (14)
The Piranha brothers (14)
Complaints (16)
Motor insurance sketch (17)
After-shave (17)
Vox pops on aftershave (17)
Police Constable Pan-Am (17)
Society for Putting Things on top of Other Things (18)
Accidents sketch (18)
The time on BBC 1 (19)
Dung (19)
Dead Indian (19)
Registry office (19)
Registrar (wife swap) (21)
Cut-price airline (22)
Fish Licence (23)
Mr Neville Shunt (24)
City gents vox pops (24)
Lifeboat (cannibalism) (26)
Undertaker's sketch (26)
Court scene (Viking) (27)
Stock Exchange report (27)
'There is nothing quite so wonderful as money' (song) (29)
Salvation fuzz (29)
Hitting on the head lessons (29)
Inspector Flying Fox of the Yard (29)
One more minute of Monty Python's Flying Circus (29)
The man who speaks in anagrams (30)
Expedition to Lake Pahoe (32)
Mr Pither (34)
Pornographic bookshop (36)
Thripshaw's disease (36)
Sherry-drinking vicar (36)
Lupins (37)
Dennis Moore: Stealing from the poor (37)
Kamikaze Scotsmen (38)
No time to lose (38)
New brain from Curry's (39)
Police helmets (43)
Father-in-law (43)
Queen Victoria Handicap (43)
Teddy Salad (CIA agent) (44)
'Conjuring Today' (44)
Icelandic Honey Week (45)
BBC News (handovers) (45)
Man In Bowler Hat
Vox pops on tax (15)
Man In Cap
Vox pops on tax (15)
Man in charge
Hitting on the head lessons (29)
Man In Dirty Raincoat
Hell's Grannies (8)
Man in Street
Vox pops on smuggling (5)
Man In Suit
Vox pops on tax (15)
Man in Tails
Ten seconds of sex (35)
Man on Left
Emigration from Surbiton to Hounslow (28)
Man on Right
Emigration from Surbiton to Hounslow (28)
Man on Roof
Vox pops on smuggling (5)
Man With Enormous Ears
City gents vox pops (24)
Man With Enormous Nose
City gents vox pops (24)
Man With Enormous Teeth
City gents vox pops (24)
Man, Mr
Mary recruitment office (30)
Bus conductor sketch (30)
Management Man
Coal mine (historical argument) (26)
Manager
Restaurant sketch (3)
Buying a bed (8)
Documentary on boxer (18)
The Idiot in Society (20)
Complaining about ant (41)
Different endings (41)
Maniac
Interesting people (11)
Mann, Mr
Language laboratory (31)
Mao Tse-tung
Communist quiz (25)
Maoists
Bingo-crazed Chinese (34)
Margaret
Biggles dictates a letter (33)
Marge
Art gallery (4)
Mario
Timmy Williams interview (19)
Mariolini
Italian lesson (1)
Mark
Trim-Jeans Theatre (28)
Martin
Insurance sketch (26)
Master of Ceremonies
Documentary on boxer (18)
Maureen
Documentary on boxer (18)
Maurice
Strangers in the night (10)
'Life of Tschaikowsky' (28)
Mayor
Icelandic saga (27)
'Mortuary Hour' (35)
MC
The wrestling epilogue (2)
McGough
Off-Licence (37)
McRettin
Scott of the Antarctic (23)
McTeagle
The Poet McTeagle (16)
Medieval Couple
Johann Gambolputty.... von Hautkopf of Ulm (6)
Mee
'Summarize Proust Competition' (31)
Membe, A
Society for Putting Things on top of Other Things (18)
Escape (from film) (18)
Member of Jury
Court scene (charades) (15)
Members
Society for Putting Things on top of Other Things (18)
Accidents sketch (18)
Mervyn
Fire brigade (31)
Our Eamonn (31)
Messenger
Erizabeth L (29)
'Russian 42nd International Clambake' (34)
Pornographic bookshop (36)
Mexican
Strangers in the night (10)
Michael
Children's interview (3)
Quiz programme - 'Wishes' (13)
Bruces (22)
Michael Miles
'Take Your Pick' (20)
Michelangelo
Michaelangelo (21)
Miles
'Spot the Loony' (38)
Military Man
Smolensk (34)
Bingo-crazed Chinese (34)
Milkmaid
Complaints (16)
Milkman
Psychiatrist milkman (16)
Complaints (16)
Déjà vu (16)
Milton
Crunchy frog (6)
Miner
Coal mine (historical argument) (26)
Minister
How far can a minister fall? (12)
'Face the Press' (14)
The Ministry of Silly Walks (14)
Secretary of State striptease (20)
Mitzi
Colin Mozart (ratcatcher) (21)
Mme. Brun
Trotsky (34)
Mock Tudor, Mrs
The public are idiots (42)
The last five miles of the M2 (42)
Show-jumping (musical) (42)
Mona Lisa
Johann Gambolputty.... von Hautkopf of Ulm (6)
Mongol
Merchant banker (30)
Monster
'Jack in a Box' (34)
Moore
Dennis Moore (37)
Lupins (37)
Dennis Moore: Stealing from the poor (37)
Dennis Moore: Redistibuting the wealth (37)
Morgan
Coal mine (historical argument) (26)
Mother
Documentary on boxer (18)
There's been a murder (22)
'Russian 42nd International Clambake' (34)
Dennis Moore: Redistibuting the wealth (37)
At home with the ant and other pets (41)
Ant communication (41)
Woody and tinny words (42)
'Most Awful Family in Britain' (45)
Icelandic Honey Week (45)
Mountaineer
Mountaineer (26)
Mounties Choir
Lumberjack song (9)
Mousebender
Cheese shop (33)
Mozart
It's Wolfgang Amadeus Mozart (1)
Famous deaths (1)
Colin Mozart (ratcatcher) (21)
Muffin
There's been a murder (22)
Europolice Song Contest (22)
Mum
Working-class playwright (2)
Policemen make wonderful friends (6)
Mynah
Beethoven's mynah bird (21)

N
Nabarro
The time on BBC 1 (19)
Narrator
Killer sheep (20)
The news for parrots (20)
The news for wombats (20)
M1 interchange built by characters from 'Paradise Lost' (35)
Natal, Dr
Bogus psychiatrists (43)
Native
The Lost World of Roiurama (29)
Nazi
The funniest joke in the world (1)
Nazi Fish
World War One (28)
Nelson
Famous deaths (1)
Film director (teeth) (24)
Nesbitt, Mrs
Submarine (26)
Neutron, Mr
Mr Neutron (44)
Teddy Salad (CIA agent) (44)
Neves, Mrs
Lifeboat (33)
Old lady snoopers (33)
Newspaper Seller
The Piranha brothers (14)
Newsreader
Stolen newsreader (3)
Newsreader arrested (5)
Erotic film (5)
Coal mine (historical argument) (26)
The BBC is short of money (28)
Puss in Boots (28)
The Minister for not listening to people (32)
Tuesday documentary/children's story/party political broadcast (32)
BBC News (handovers) (45)
Nid
Pornographic bookshop (36)
Nigel
Timmy Williams interview (19)
Nigger-Baiter, Mrs
Mrs Niggerbaiter explodes (28)
Noel
How to rid the world of all known diseases (28)
Non-Gorilla, Mrs
Piston engine (a bargain) (43)
Non-Robinson, Mrs
Boxing commentary (43)
Piston engine (a bargain) (43)
Non-Smoker, Mrs
Piston engine (a bargain) (43)
Norman
Nudge nudge (3)
Election Night Special (Silly and Sensible Parties) (19)
Norman Hackforth
Police station (7)
Norris, Miss
Attila the Nun (20)
Norwegian
Party Political Broadcast on Behalf of the Norwegian Party (40)
Notlob
Psychiatry - silly sketch (13)
Operating theatre (squatters) (13)
Nude Man
A choice of viewing (17)
A naked man (35)
Nudge
'Crackpot Religions Ltd' (24)
Nun
Mr and Mrs Git (21)
Nurse
Me Doctor (13)
Gumby brain specialist (32)
Mr Pither (34)
Clodagh Rodgers (34)
Bogus psychiatrists (43)
Hamlet and Ophelia (43)
Queen Victoria Handicap (43)
A doctor whose patients are stabbed by his nurse (45)

O
O' Tracey, Mrs
The Piranha brothers (14)
O, Mrs
What the stars foretell (37)
Doctor (37)
Oates
Scott of the Antarctic (23)
Officer
Picasso/cycling race (1)
The funniest joke in the world (1)
The smuggler (5)
Election Night Special (Silly and Sensible Parties) (19)
World War One (28)
Old lady snoopers (33)
'Russian 42nd International Clambake' (34)
Official
Tax on thingy (15)
The Olympic hide-and-seek final (35)
Old Idiot
The Idiot in Society (20)
Old lady
Mr Pither (34)
Old Lady
Poetry reading (ants) (41)
Old Man
The news for parrots (20)
Omnes
Court scene (witness in coffin/Cardinal Richelieu) (3)
Operating Gumbys
Gumby brain specialist (32)
Ophelia
Hamlet and Ophelia (43)
Orbiter, Mr
Gestures to indicate pauses in a televised talk (30)
Organs
'Probe-around' on crime (13)
The Piranha brothers (14)
Oscar
The Oscar Wilde sketch (39)
Ostrich
Strangers in the night (10)
Othello
Tory Housewives Clean-up Campaign (32)
Other Newsreader
Newsreader arrested (5)
Others
RAF banter (42)
Teddy Salad (CIA agent) (44)
Others, The
Secret Service dentists (4)
Otto
The funniest joke in the world (1)
Our Hero
Six more minutes of Monty Python's Flying Circus (29)

P
PA Announcement
Ideal Loon Exhibition (37)
PA System
Buying an ant (41)
Padget
Film director (teeth) (24)
Padre
Seven Brides for Seven Brothers (18)
'Ypres 1914' (25)
Parrot
Crunchy frog (6)
Killer sheep (20)
Expedition to Lake Pahoe (32)
Parson
Dennis Moore (37)
Pasolini
Pasolini's film 'The Third Test Match' (39)
Patient
Hospital run by RSM (26)
Boxing commentary (43)
Dentists (43)
Patrice
Everest climbed by hairdressers (31)
Paul Fox
Puss in Boots (28)
Peaches
Penguins (38)
Pearson
Pet conversions (10)
Peepee
The free repetition of doubtful words sketch, by an underrated author (36)
Peer
'Mortuary Hour' (35)
Pepperpot
Whizzo butter (1)
Picasso/cycling race (1)
French lecture on sheep-aircraft (2)
Court scene (witness in coffin/Cardinal Richelieu) (3)
Vox pops on smuggling (5)
Letters and vox pops (5)
Vox pops (6)
Lumberjack song (9)
The Minehead by-election (12)
Mrs Thing and Mrs Entity (21)
Colin Mozart (ratcatcher) (21)
The death of Mary Queen of Scots (22)
Exploding penguin on TV set (22)
Submarine (26)
Anagram quiz (30)
Tory Housewives Clean-up Campaign (32)
Pepperpots
Whizzo butter (1)
Person
Albatross (13)
'Most Awful Family in Britain' (45)
Peter
Timmy Williams interview (19)
Test match (20)
International Wife-Swapping (39)
Peter Woods
Show-jumping (musical) (42)
Petula
Documentary on boxer (18)
Phelps
Psychiatry - silly sketch (13)
Phil
French subtitled film (23)
Philip Jenkinson
Philip Jenkinson on Cheese Westerns (33)
Sam Peckinpah's 'Salad Days' (33)
Phillips, Mr
Visitors from Coventry (12)
Pig
Johann Gambolputty.... von Hautkopf of Ulm (6)
Strangers in the night (10)
Police station (silly voices) (12)
Pilot
Flying lessons (16)
Hijacked plane (to Luton) (16)
Bomb on plane (35)
RAF banter (42)
Woody and tinny words (42)
Pilots
Hijacked plane (to Luton) (16)
Pinnet, Mrs
New cooker sketch (14)
Pither
Mr Pither (34)
Accidents involving food (34)
Clodagh Rodgers (34)
Trotsky (34)
Smolensk (34)
Bingo-crazed Chinese (34)
'Russian 42nd International Clambake' (34)
Planner
The last five miles of the M2 (42)
Plastic
Arthur Tree (10)
Plumber
Montgolfier Brothers (40)
Podgorny, Mrs
Man turns into Scotsman (7)
Police station (7)
Polevaulter
The man who contradicts people (22)
Police Chief
World War One (28)
Puss in Boots (28)
Policeman
Police raid (5)
Johann Gambolputty.... von Hautkopf of Ulm (6)
Vox pops (6)
Policemen make wonderful friends (6)
A Scotsman on a horse (6)
Police station (7)
Hell's Grannies (8)
Quiz programme - 'Wishes' (13)
'Probe-around' on crime (13)
Operating theatre (squatters) (13)
The Piranha brothers (14)
Vox pops on aftershave (17)
Police Constable Pan-Am (17)
Accidents sketch (18)
Dead Indian (19)
Dirty Hungarian phrasebook (25)
Court (phrasebook) (25)
Court scene - multiple murderer (27)
One more minute of Monty Python's Flying Circus (29)
'Nationwide' (43)
Police helmets (43)
Policemen
Johann Gambolputty.... von Hautkopf of Ulm (6)
'Probe-around' on crime (13)
Politician
Tax on thingy (15)
Tuesday documentary/children's story/party political broadcast (32)
Party Political Broadcast (choreographed) (38)
Porter
The mouse problem (2)
Dead parrot (8)
Post Office Worker
Scott of the Sahara (23)
Postman
'Most Awful Family in Britain' (45)
Potter, Mr
Living room on pavement (17)
Potter, Mrs
Living room on pavement (17)
Praline
Vox pops (6)
Crunchy frog (6)
Dead parrot (8)
Current affairs (18)
Fish Licence (23)
Premise, Mrs
Mrs Premise and Mrs Conclusion visit Jean Paul Satre (27)
Presenter
Falling from building (12)
'Spectrum' - talking about things (12)
The Minehead by-election (12)
How far can a minister fall? (12)
The Piranha brothers (14)
'Blackmail' (18)
Long John Silver Impersonators v. Bournemouth Gynaecologist (23)
Crossing the Atlantic on a tricycle (24)
Interview in filing cabinet (24)
Communist quiz (25)
Submarine (26)
Farming club (28)
'Life of Tschaikowsky' (28)
'The Money Programme' (29)
'There is nothing quite so wonderful as money' (song) (29)
Anagram quiz (30)
Theory on Brontosauruses by Anne Elk (Miss) (31)
Molluscs - 'live' TV documentary (32)
Tuesday documentary/children's story/party political broadcast (32)
'Storage jars' (33)
Bull-fighting (35)
Penguins (38)
'Spot the Loony' (38)
Louis XIV (40)
A room in Polonius's house (43)
Queen Victoria Handicap (43)
'Most Awful Family in Britain' (45)
Cricket match (assegais) (45)
BBC News (handovers) (45)
President Nixon
Police station (silly voices) (12)
Presiding General
Courtmartial (42)
Basingstoke in Westphalia (42)
'Anything Goes In' (song) (42)
Priest
'Crackpot Religions Ltd' (24)
Trim-Jeans Theatre (28)
Prime Minister
Teddy Salad (CIA agent) (44)
Prince
The Oscar Wilde sketch (39)
Principal Boy
Puss in Boots (28)
Prisoner
Court scene (witness in coffin/Cardinal Richelieu) (3)
Private
Picasso/cycling race (1)
Producer
Rival documentaries (38)
Professor
Eighteenth-century social legislation (11)
'Spectrum' - talking about things (12)
Killer sheep (20)
Prices on the planet Algon (35)
Penguins (38)
'Most Awful Family in Britain' (45)
Prologue
Restaurant (abuse/cannibalism) (13)
Property Dealer
Live from Epsom (43)
Proprietor
Mr Pither (34)
Prosecuting Counsel
Court scene (Viking) (27)
Psychiatrist
Psychiatry - silly sketch (13)
Bogus psychiatrists (43)
Pudifoot, Mr
The man who says things in a very roundabout way (26)

Q
Queen
Erizabeth L (29)
Fraud film squad (29)
Queen Victoria
Poetry reading (ants) (41)
Queen Victoria Handicap (43)

R
Radio
The funniest joke in the world (1)
Art gallery strike (25)
Radio Announcer
The death of Mary Queen of Scots (22)
Ralph Garibaldi
'Most Awful Family in Britain' (45)
Ramsay MacDonald
Ramsay MacDonald striptease (24)
Randall
Court scene - multiple murderer (27)
Ratcatcher
Ratcatcher (20)
Wainscotting (20)
Rating
Expedition to Lake Pahoe (32)
Raymond
Raymond Luxury Yacht interview (19)
Reader
'Redgauntlet' (38)
George III (40)
Real Manager
Buying an ant (41)
Receptionist
Psychiatry - silly sketch (13)
Hitting on the head lessons (29)
Kamikaze Scotsmen (38)
Redcoat
The audit (7)
The Olympic hide-and-seek final (35)
Referee
Registrar (wife swap) (21)
Reg
Non-illegal robbery (6)
The Spanish Inquisition (15)
Jokes and novelties salesman (15)
Reg Moss
Picasso/cycling race (1)
Reggie
Insurance sketch (26)
Registrar
Registry office (19)
Registrar (wife swap) (21)
Reporter
Hell's Grannies (8)
Timmy Williams interview (19)
'Nationwide' (43)
Police helmets (43)
Boxing match aftermath (43)
Reverend Belling
Silly vicar (21)
Richard
Hospital for over-actors (25)
Richard Baker
The news with Richard Baker (33)
Dickie Attenborough (39)
Richard III
Hospital for over-actors (25)
Richelieu
Historical impersonations (13)
Rickman
International Wife-Swapping (39)
Ricky
Everest climbed by hairdressers (31)
Rita
Batley Townswomens' Guild presents the Battle of Pearl Harbour (11)
Batley Townswomen's Guild presents the first heart transplant (22)
Robber
Walk-on part in sketch (10)
Bank robber (lingerie shop) (10)
Robert
How far can a minister fall? (12)
Father-in-law (43)
Robin
'The Attila the Hun Show' (20)
Robinson, Mr
The Cheap-Laughs (35)
Robinson, Mrs
The Cheap-Laughs (35)
Piston engine (a bargain) (43)
Rodent
Strangers in the night (10)
Rodgers
'Storage jars' (33)
Rodgers, Miss
Girls' boarding school (26)
Roger
Strangers in the night (10)
Roger Last
'Is there?'...life after death? (36)
Roman Centurion
Pet conversions (10)
Ron
The first man to jump the Channel (10)
Tunnelling from Godalming to Java (10)
Ronald
'Summarize Proust Competition' (31)
Ronettes, The
George III (40)
Rosamund
Ken Shabby (12)
Ross
It's the Arts (1)
Roy
Mosquito hunters (21)
RSM
Self-defence (4)
Mary recruitment office (30)
Bus conductor sketch (30)
Army captain as clown (30)
Kamikaze Scotsmen (38)
No time to lose (38)
RSPCA Man
How to feed a goldfish (26)
Rustic
Flying Sheep (2)

S
S, Mrs
Mrs Niggerbaiter explodes (28)
Vicar/salesman (28)
Sailor
Lifeboat (cannibalism) (26)
Sales Manager
Poets (17)
Salesman
New brain from Curry's (39)
Samson
Blood donor (39)
Sappenheim
'TV4 or not TV4' diskussion (37)
Sartre, Mrs
Mrs Premise and Mrs Conclusion visit Jean Paul Satre (27)
Scene Shifter
Puss in Boots (28)
Schlick
Scott of the Antarctic (23)
Schoolmaster
Seven Brides for Seven Brothers (18)
Scientist
Penguins (38)
Scot
The man who speaks only the middles of words (26)
Scots Soldier
Kamikaze Scotsmen (38)
Scotsman
Letters and vox pops (5)
Vox pops (6)
Scott
Scott of the Antarctic (23)
'Spot the Loony' (38)
Scrap Man
Post box ceremony (44)
Scum, Mrs
Teddy Salad (CIA agent) (44)
Secretary
Flying lessons (16)
Travel agent (31)
Watney's Red Barrel (31)
Biggles dictates a letter (33)
Secretary of State
Teddy Salad (CIA agent) (44)
Security Man
The last five miles of the M2 (42)
Senior General
'Russian 42nd International Clambake' (34)
Sergeant
Confuse-a-Cat (5)
Police station (7)
Army protection racket (8)
Police station (silly voices) (12)
Stonehenge (13)
Mr Attila the Hun (13)
Escape (from film) (18)
Camp square-bashing (22)
'Ypres 1914' - abandoned (25)
'Ypres 1914' (25)
Several
No time to lose (38)
Shabby
Ken Shabby (12)
Vox pops on aftershave (17)
'Crackpot Religions Ltd' (24)
Shakespeare
Shakespeare (21)
Shaw
The Oscar Wilde sketch (39)
She
Erotic film (5)
Man turns into Scotsman (7)
Police station (7)
Restaurant (abuse/cannibalism) (13)
Poets (17)
A choice of viewing (17)
Silly disturbances (the Rev. Arthur Belling) (36)
Shelley
Poetry reading (ants) (41)
Shirley
'Mortuary Hour' (35)
Shopkeeper
Dead parrot (8)
Pet conversions (10)
Tobacconists (prostitute advert) (14)
The Ministry of Silly Walks (14)
Shoplifter
Police Constable Pan-Am (17)
Shoplifter's Mate
Police Constable Pan-Am (17)
'Shrill' Man
Job Hunter (24)
Shunt
Mr Neville Shunt (24)
Signalman
'Spectrum' - talking about things (12)
Simmel, Mrs
The Piranha brothers (14)
Singer
Song ('And did those feet') (4)
Art critic (4)
Self-defence (4)
Singers
Dennis Moore: Stealing from the poor (37)
Sir
Kilimanjaro expedition (double vision) (9)
Sir Dividends
Louis XIV (40)
Sir Jane
Expedition to Lake Pahoe (32)
Sir John
Expedition to Lake Pahoe (32)
Sir Kenneth
'Boxing tonight' - Jack Bodell v. Kenneth Clark (37)
Sir Pratt
Appeal on behalf of extremely rich people (45)
Sir Robert
'Archaeology Today' (21)
Sir Vincent
'Face the Press' (14)
New cooker sketch (14)
Sir William
Society for Putting Things on top of Other Things (18)
Escape (from film) (18)
Accidents sketch (18)
Sister
Me Doctor (13)
Skeleton
Vicar/salesman (28)
Sm, Mr
The man who speaks only the beginnings of words (26)
The man who speaks only the middles of words (26)
Smailes, Mr
Teddy Salad (CIA agent) (44)
Smailes, Mrs
Mr Neutron (44)
Smith
Seven Brides for Seven Brothers (18)
Kamikaze Scotsmen (38)
Smoker, Mrs
Piston engine (a bargain) (43)
Soldier
Upperclass Twit of the Year (12)
School prize-giving (19)
'Russian 42nd International Clambake' (34)
Kamikaze Scotsmen (38)
Soldiers
Camp square-bashing (22)
Soloist
'Summarize Proust Competition' (31)
Solomon
Art gallery strike (25)
Son
There's been a murder (22)
Mrs Niggerbaiter explodes (28)
Salvation fuzz (29)
'Most Awful Family in Britain' (45)
Song
Secret Service dentists (4)
Dennis Moore (37)
Lupins (37)
Dennis Moore: Stealing from the poor (37)
Sound Man
The Poet McTeagle (16)
Timmy Williams interview (19)
Southener
Marriage guidance counsellor (2)
Spaniard
Pornographic bookshop (36)
Specialist
Cosmetic surgery (22)
Hospital for over-actors (25)
Gumby brain specialist (32)
Spiny Norman
The man who collects birdwatcher's eggs (26)
Spotter
Camel spotting (7)
You're no fun any more (7)
The audit (7)
Spreaders
Inspector Flying Fox of the Yard (29)
One more minute of Monty Python's Flying Circus (29)
Squadron Leader
RAF banter (42)
Squatter
Operating theatre (squatters) (13)
Squire
Dennis Moore (37)
Starter
The Olympic hide-and-seek final (35)
Stebbins
Schoolboys' Life Assurance Company (28)
Stewardess
Bomb on plane (35)
Stig
Silly job interview (5)
The Piranha brothers (14)
French subtitled film (23)
Stockbroker
The mouse problem (2)
Letters and vox pops (5)
Vox pops on full frontal nudity (8)
The Minehead by-election (12)
Stokes, Mrs
Mr and Mrs Git (21)
Stools, Mr
Interesting people (11)
Storyteller
Children's stories (3)
Strange Man
'Most Awful Family in Britain' (45)
Superboy
Bicycle repair man (3)
Superintendent
Court scene (Viking) (27)
Superman
Bicycle repair man (3)
Supermen
Bicycle repair man (3)
Surgeon
Agatha Christie sketch (11)
Operating theatre (squatters) (13)
Gumby brain specialist (32)
Ant communication (41)
Svensson
'Spot the Loony' (38)
Swalk
'Mortuary Hour' (35)
Swedish Person
Penguins (38)

T
T. F. Gumby
Gumby brain specialist (32)
Taggart
Kamikaze Scotsmen (38)
Tape Recorder
Homicidal barber (9)
Taxi
Bingo-crazed Chinese (34)
Teacher
Italian lesson (1)
Technician
'Redgauntlet' (38)
No time to lose (38)
Tenant
Mystico and Janet - flats built by hypnosis (35)
Tennyson
Living room on pavement (17)
Poetry reading (ants) (41)
Tenors
'Summarize Proust Competition' (31)
Terry
Children's interview (3)
Terry Gilliam
'Mortuary Hour' (35)
Theresamanbehindyer
Agatha Christie sketch (11)
Three Naked Ladies
Johann Gambolputty.... von Hautkopf of Ulm (6)
Thripshaw
The man who says words in the wrong order (36)
Thripshaw's disease (36)
Throat
'TV4 or not TV4' diskussion (37)
Tick
Language laboratory (31)
Tid, Mr
Architect sketch (17)
Tidwell
Schoolboys' Life Assurance Company (28)
Timmy
Timmy Williams interview (19)
Tinker
Rival documentaries (38)
Tirpitz
Zeppelin (40)
Toad
Film director (teeth) (24)
Toastmaster
Society for Putting Things on top of Other Things (18)
Tobacconist
Dirty Hungarian phrasebook (25)
Tony
Agatha Christie Sketch (Railway Timetables) (24)
Toogood
No time to lose (38)
Rival documentaries (38)
Toupee Manager
Toupee (41)
Tourist
Travel agent (31)
Watney's Red Barrel (31)
Theory on Brontosauruses by Anne Elk (Miss) (31)
Trainer
Documentary on boxer (18)
Trapper
Teddy Salad (CIA agent) (44)
Tree
Arthur Tree (10)
Trench
Picasso/cycling race (1)
Trepidatious, Mrs
What the stars foretell (37)
Doctor (37)
Trevor
Quiz programme - 'Wishes' (13)
Turpin, Mrs
Cut-price airline (22)
Tussaud, Mr
The show so far (33)
TV Announcer
Exploding penguin on TV set (22)
Two Dancers
Johann Gambolputty.... von Hautkopf of Ulm (6)
Two Girls
Seven Brides for Seven Brothers (18)

U
Uncle Sam
Job Hunter (24)
Uncle Tom
'The Attila the Hun Show' (20)
Unction
Trailer (10)
Vocational Guidance Counseller (chartered accountant) (10)
Undertaker
Interruptions (11)
Agatha Christie sketch (11)
Literary football discussion (11)
Undertaker's sketch (26)
Upperclass Twit
Police station (silly voices) (12)
Urn, The
Dickie Attenborough (39)
Usher
Court scene (Viking) (27)

V
Valerie Garibaldi
'Most Awful Family in Britain' (45)
Van der Berg
Secret Service dentists (4)
Varley, Mrs
Mrs Premise and Mrs Conclusion visit Jean Paul Satre (27)
Venus
Art gallery strike (25)
Vera
Strangers in the night (10)
Vercotti
The Piranha brothers (14)
Vercotti, Mr
The first man to jump the Channel (10)
Tunnelling from Godalming to Java (10)
Verity
Buying a bed (8)
Verity, Mr
Buying a bed (8)
Vernon, Mr
The man who finishes other peoples sentences (45)
Veronica
'Party Hints' with Veronica Smalls (31)
Verybigliar, Mr
Mystico and Janet - flats built by hypnosis (35)
Vet
Confuse-a-Cat (5)
Vibrating, Mr
Hitting on the head lessons (29)
Vicar
The mouse problem (2)
The smuggler (5)
Vox pops (6)
Gorilla librarian (10)
Motor insurance sketch (17)
'The Bishop' (17)
Cut-price airline (22)
Vicar/salesman (28)
Silly disturbances (the Rev. Arthur Belling) (36)
Sherry-drinking vicar (36)
The dirty vicar sketch (39)
Vicky
Picasso/cycling race (1)
Victor
The visitors (9)
Viking
Arthur 'Two-Sheds' Jackson (1)
The mouse problem (2)
Johann Gambolputty.... von Hautkopf of Ulm (6)
Vocational Guidance Counseller (chartered accountant) (10)
Killer sheep (20)
Icelandic saga (27)
Climbing the north face of the Uxbridge Road (33)
Cheese shop (33)
Vikings
Spam (25)
Vince
The Piranha brothers (14)
Von Bülow
Zeppelin (40)
Von Ribbentrop
Mr Hilter (12)
The Minehead by-election (12)

W
Waiter
Restaurant sketch (3)
Restaurant (abuse/cannibalism) (13)
Timmy Williams interview (19)
The man who collects birdwatcher's eggs (26)
The silliest sketch we've ever done (32)
Waitress
The man who is alternately rude and polite (18)
Documentary on boxer (18)
Spam (25)
Wallet
Bingo-crazed Chinese (34)
Walters
Interesting people (11)
Courtmartial (42)
Basingstoke in Westphalia (42)
'Anything Goes In' (song) (42)
Wang
'Mortuary Hour' (35)
Watkins
Army protection racket (8)
Watson
Silly doctor sketch (immediately abandoned) (21)
Mr and Mrs Git (21)
Wensleydale
Cheese shop (33)
Whicker
Mrs Premise and Mrs Conclusion visit Jean Paul Satre (27)
Whicker Island (27)
Whistler
The Oscar Wilde sketch (39)
Whole Court
Court scene (charades) (15)
Wife
Bicycle repair man (3)
Art critic (4)
Man turns into Scotsman (7)
Hell's Grannies (8)
Walk-on part in sketch (10)
Interesting people (11)
Michaelangelo (21)
Pornographic bookshop (36)
Wiggin
Historical impersonations (13)
Wiggin, Mr
Architect sketch (17)
Williams
A doctor whose patients are stabbed by his nurse (45)
Wills, Mrs
Flying lessons (16)
Window Cleaner
The mouse problem (2)
Wingco
RAF banter (42)
Woman
Vox pops on smuggling (5)
Burglar/encyclopedia salesman (5)
Wainscotting (20)
'Take Your Pick' (20)
City gents vox pops (24)
Salvation fuzz (29)
Everest climbed by hairdressers (31)
Expedition to Lake Pahoe (32)
Sam Peckinpah's 'Salad Days' (33)
Complaining about ant (41)
Woman Journalist
Letters and vox pops (5)
Woman's voice
The death of Mary Queen of Scots (22)
Women
Police helmets (43)
Wordsworth
Poets (17)
Poetry reading (ants) (41)
Worral, Mrs
New brain from Curry's (39)
Writer
Twentieth-century vole (6)
Writers
Twentieth-century vole (6)

X
Ximinez
The Spanish Inquisition (15)
Photos of Uncle Ted (Spanish Inquisition) (15)
Court scene (charades) (15)

Y
Yahlt
Court (phrasebook) (25)
Yokel
The Minehead by-election (12)
Young Lady
Photos of Uncle Ted (Spanish Inquisition) (15)
Young Man
Vox pops on smuggling (5)
Police raid (5)
Hell's Grannies (8)

Z
Zambesi
New brain from Curry's (39)
Zanie
Flying lessons (16)
Zatapathique
'Bing Tiddle Tiddle Bong' (song) (22)
Zeppelin
Zeppelin (40)
Zorba
Molluscs - 'live' TV documentary (32)
Zyndersky, Mr
Complaints office (41)